==> okular-19.04.1.tar.xz: okular-19.04.1/generators/poppler/config-okular-poppler.h.cmake <==
/* Defined if we have the 0.24 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_24 1

/* Defined if we have the 0.28 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_28 1

/* Defined if we have the 0.36 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_36 1

/* Defined if we have the 0.37 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_37 1

/* Defined if we have the 0.50 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_50 1

/* Defined if we have the 0.51 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_51 1

/* Defined if we have the 0.53 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_53 1

/* Defined if we have the 0.58 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_58 1

/* Defined if we have the 0.60 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_60 1

/* Defined if we have the 0.62 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_62 1

/* Defined if we have the 0.63 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_63 1

/* Defined if we have the 0.64 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_64 1

/* Defined if we have the 0.65 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_65 1

/* Defined if we have the 0.68 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_68 1

/* Defined if we have the 0.69 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_69 1

/* Defined if we have the 0.73 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_73 1

==> okular_19.12.3.orig.tar.xz: okular-19.12.3/generators/poppler/config-okular-poppler.h.cmake <==
/* Defined if we have the 0.24 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_24 1

/* Defined if we have the 0.28 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_28 1

/* Defined if we have the 0.36 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_36 1

/* Defined if we have the 0.37 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_37 1

/* Defined if we have the 0.50 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_50 1

/* Defined if we have the 0.51 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_51 1

/* Defined if we have the 0.53 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_53 1

/* Defined if we have the 0.58 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_58 1

/* Defined if we have the 0.60 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_60 1

/* Defined if we have the 0.62 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_62 1

/* Defined if we have the 0.63 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_63 1

/* Defined if we have the 0.64 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_64 1

/* Defined if we have the 0.65 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_65 1

/* Defined if we have the 0.68 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_68 1

/* Defined if we have the 0.69 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_69 1

/* Defined if we have the 0.73 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_73 1

/* Defined if we have the 0.79 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_79 1

/* Defined if we have the 0.80 version of the Poppler library */
#cmakedefine HAVE_POPPLER_0_80 1
